<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				version="1.0" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:exsl="http://exslt.org/common"
				extension-element-prefixes="exsl">
	
	<xsl:template match="/">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">

			<!-- defines page layout -->
			<fo:layout-master-set>
				<fo:simple-page-master master-name="simple" page-width="28cm" page-height="22cm" margin-top="0.5cm" margin-bottom="0.5cm" margin-left="0.5cm" margin-right="0.5cm">
					<fo:region-before extent="0.5cm"/>
					<fo:region-body margin-top="0.5cm" margin-bottom="0.5cm"/>
				</fo:simple-page-master>
			</fo:layout-master-set>


			<!-- defines the content -->
			<fo:page-sequence master-reference="simple">
				<fo:static-content flow-name="xsl-region-before" font-size="8pt">
					<fo:block  text-align="right">
					<fo:page-number/>
					<fo:inline>/</fo:inline>
					<fo:page-number-citation ref-id="terminator"/>
					</fo:block>
				</fo:static-content>

				<xsl:element name="fo:flow">
					<xsl:attribute name="flow-name">xsl-region-body</xsl:attribute>
					<xsl:if test="boolean(exsl:node-set($config)/List/@font-family)">
						<xsl:attribute name="font-family">
							<xsl:value-of select="exsl:node-set($config)/List/@font-family"/>
						</xsl:attribute>
					</xsl:if>

					<fo:block font-size="14pt" font-weight="bold" text-align="center">
					<xsl:value-of select="//MetaData/List/Item[1]/@FlPlnCmpntDefNm"/> Report
					</fo:block>
				
					<fo:table font-size="8pt">
						<xsl:if test="count(exsl:node-set($config)/List/Item) = 0">
							<xsl:variable name="width" select="27 div count(//MetaData/List/Item)"/>
							<!-- Column width setting  -->
							<xsl:for-each select="//MetaData/List/Item">
							<fo:table-column >
								<xsl:attribute name="column-width">
									<xsl:value-of select="$width"/>
									<xsl:text>cm</xsl:text> 
								</xsl:attribute>
							</fo:table-column>
							</xsl:for-each>

						</xsl:if>
						<xsl:if test="count(exsl:node-set($config)/List/Item) > 0">
							<xsl:variable name="width" select="27 div count(exsl:node-set($config)/List/Item)"/>
							<xsl:for-each select="exsl:node-set($config)/List/Item">
							<fo:table-column >
								<xsl:attribute name="column-width">
									<xsl:value-of select="$width"/>
									<xsl:text>cm</xsl:text> 
								</xsl:attribute>
							</fo:table-column>
							</xsl:for-each>

						</xsl:if>
						
						<!-- Header -->
						<fo:table-header font-weight="bold" color="white" background-color="gray">
							<fo:table-row>
								<xsl:apply-templates select="//MetaData"/>
								<xsl:call-template name="writeHeader"/>
								
							</fo:table-row>													
						</fo:table-header>

						<!-- Records -->
						<fo:table-body>
							<xsl:for-each select="//Data/List/Item">
							<xsl:variable name="pos" select="position()" />										
							
									<xsl:element name="fo:table-row">
										
										<xsl:if test="($pos mod 2) = 1">
											<xsl:attribute name="background-color">white</xsl:attribute>
										</xsl:if>
										<xsl:if test="($pos mod 2) = 0">
											<xsl:attribute name="background-color">silver</xsl:attribute>
										</xsl:if>
										
										<xsl:variable name="curDataListItem" select="."/>
										<xsl:if test="count(exsl:node-set($config)/List/Item) = 0">
											<xsl:for-each select="//MetaData/List/Item">
											<xsl:variable name="colName" select="@FlPlnCmpntAttrDefColNm" />
												<fo:table-cell padding="2pt">
													<fo:block text-align="start">
														<xsl:value-of select="$curDataListItem/@*[name()=$colName]" />
													</fo:block>
												</fo:table-cell>
											</xsl:for-each>
										</xsl:if>										

										<xsl:if test="count(exsl:node-set($config)/List/Item) > 0">
											<xsl:for-each select="exsl:node-set($config)/List/Item">
											<xsl:variable name="colName" select="@FlPlnCmpntAttrDefColNm" />
												<fo:table-cell padding="2pt">
													<fo:block text-align="start">
														<xsl:value-of select="$curDataListItem/@*[name()=$colName]" />
													</fo:block>
												</fo:table-cell>
											</xsl:for-each>
										</xsl:if>										

									</xsl:element>	
									

							</xsl:for-each>
							<!-- Total -->
							<fo:table-row padding="3pt">
								
								<xsl:element name="fo:table-cell">
									<xsl:attribute name="number-columns-spanned">
										<xsl:value-of select="count(/ResultList/MetaData/List/Item)"/>
									</xsl:attribute>
									<xsl:attribute name="border-top" >solid black</xsl:attribute>
									<xsl:attribute name="border-bottom" >solid black</xsl:attribute>
									
									<fo:block text-align="start" >Total:<xsl:value-of select="count(/ResultList/Data/List/Item)" /></fo:block>
									
								</xsl:element>
								
							</fo:table-row>
						</fo:table-body>
					</fo:table>

					<fo:block id="terminator"/>

				</xsl:element>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>

	<xsl:template name="writeHeader">
		<xsl:if test="count(exsl:node-set($config)/List/Item) = 0">
			<xsl:for-each select="//MetaData/List/Item">
				<fo:table-cell border-top="solid black" border-bottom="solid black" padding="3pt">
					<fo:block>
					<xsl:value-of select="@FlPlnCmpntAttrDefCapt"/>
					</fo:block>
				</fo:table-cell>
			</xsl:for-each>	
		</xsl:if>	

		<xsl:if test="count(exsl:node-set($config)/List/Item) > 0">
			<xsl:variable name="metaDataList" select="//MetaData/List"/>
			
			<xsl:for-each select="exsl:node-set($config)/List/Item">
				<xsl:variable name="curFlPlnCmpntAttrDefColNm" select="@FlPlnCmpntAttrDefColNm" />
				<fo:table-cell border-top="solid black" border-bottom="solid black" padding="3pt">
					<fo:block>
					<xsl:value-of select="$metaDataList/Item[@FlPlnCmpntAttrDefColNm = $curFlPlnCmpntAttrDefColNm]/@FlPlnCmpntAttrDefCapt"/>
					</fo:block>
				</fo:table-cell>
			</xsl:for-each>	
		</xsl:if>
		
	</xsl:template>

	<!-- ======================================================================================================= 
		Configuration 
	
		By default, it prints columns from the meta data of XML data source which are those you selected in the Output Fields of Advanced Query. 
		
		You can also specified the columns to be printed by editing the report layout file(General.xsl):
		
		1)	Open General.xsl with any XML editor
		2)	Go to the bottom of the file
		3)	Specify the columns by putting them in the list inside element <xsl:variable name="config">. 
		For example:
			<xsl:variable name="config">
				<List>
					<Item FlPlnCmpntAttrDefColNm="NameFullPath"/>
					<Item FlPlnCmpntAttrDefColNm="TS_FlPlnCmpntDef.FlPlnCmpntDefNm"/>
				</List>
			</xsl:variable>
		It will print columns:  NameFullPath and TS_FlPlnCmpntDef.FlPlnCmpntDefNm. 
		Please note that the specified columns has to be included in the columns from meta data of XML data source.
	
		You can also specify the font used in this report by adding a font-family attribute in the List element
		
		For example:
			<List font-family="Arial">
		It will use the Airal font.
		
		Note: The only difference between General.xsl and General_Arial.xsl is that General_Arial.xsl specifies Airal font.
	
		========================================================================================================
	-->

	<xsl:variable name="config">

		<List font-family="Arial">

			<!--
			<Item FlPlnCmpntAttrDefColNm="NameFullPath"/>
			<Item FlPlnCmpntAttrDefColNm="TS_FlPlnCmpntDef.FlPlnCmpntDefNm"/>
			-->
		</List>

	</xsl:variable>

</xsl:stylesheet>